;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "frameshot" "20251101.2212"
  "Take screenshots of a frame."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/frameshot"
  :commit "89ca25879b4c55da049f771870926a27bbfb1066"
  :revdesc "89ca25879b4c"
  :keywords '("multimedia")
  :authors '(("Jonas Bernoulli" . "emacs.frameshot@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.frameshot@jonas.bernoulli.dev")))
